@@ -319,5 +319,7 @@ gboolean        fr_window_file_list_drag_data_get      (FrWindow         *window
 						        GtkSelectionData *selection_data,
 						        GList            *path_list);
 void            fr_window_update_dialog_closed         (FrWindow         *window);
+void		fr_window_dnd_extraction_finished      (FrWindow	 *window,
+							gboolean	  error);
 
 #endif /* FR_WINDOW_H */
